Enum AstBasicTypeSpecifier
pub enum AstBasicTypeSpecifier {
BuiltinType {
specifier: String,
loc: SourceLocation,
},
Alias {
alias_name: AstUniqueName,
loc: SourceLocation,
},
}Expand description
A basic type specifier.
A basic type consists of one or more specifiers. In the example below the basic type is ‘unsigned long int’ and consists of three built-in type specifiers.
unsigned long int salary = 0;
~~~~~~~~ ~~~~ ~~~The following basic type has one alias specifier.
typedef float F32;
F32 temperature = 0.0f;
~~~Variants
Implementations
impl AstBasicTypeSpecifier
impl AstBasicTypeSpecifier
pub fn location(&self) -> SourceLocation
pub fn location(&self) -> SourceLocation
The source location of the specifier.