Enum AstConstantValue

pub enum AstConstantValue {
    Integer(AstConstantInteger),
    Fp(AstConstantFp),
    Pointer(AstType, AstAddressConstant),
    String {
        ascii: Vec<String>,
    },
}
A constant value that was either parsed from a literal or was evaluated from a constant expression.

Variants



Integer(AstConstantInteger)

A constant integer value.



Fp(AstConstantFp)



Pointer(AstType, AstAddressConstant)

A pointer address constant from evaluating a static storage pointer initializer. See AstAddressConstant for more examples.

static int *p = 0;
static char *str = "hello";


String

A constant string value from evaluating a static storage character array initializer.

static char text[4] = "abcd";

Fields

ascii: Vec<String>

Implementations



impl AstConstantValue

pub fn get_ast_type(&self) -> AstType

Gets the AST type of the constant value.

pub fn is_pointer_address_constant(&self) -> bool

Is the constant value a pointer address constant?

pub fn is_zero(&self) -> bool

Is the constant value equal to zero?

pub fn has_negative_value(&self) -> bool

Is the constant value below zero? Always false for unsigned types.

pub fn cast_to(self, cast_to_type: &AstType) -> Self

Converts the constant value to a different type, performing the appropriate cast for C.