Enum AstExpressionFlag
#[repr(u8)]pub enum AstExpressionFlag {
IsConstant = 1,
IsStaticStorageInit = 2,
HasParens = 4,
PromotedToInt = 8,
}Expand description
A flag which indicates a property of an AST expression.
Variants
IsConstant = 1
The expression is a constant (literal).
IsStaticStorageInit = 2
The expression is an initializer for a static storage variable.
HasParens = 4
The expression is enclosed in parentheses in the source code.
PromotedToInt = 8
The expression’s type was promoted to ‘int’ due to integer promotion rules.