Enum AstExpressionKind

pub enum AstExpressionKind {
Show 17 variants Unary { op: AstUnaryOp, operand: Box<AstExpression>, }, Binary { op: AstBinaryOp, lhs: Box<AstExpression>, rhs: Box<AstExpression>, }, Assignment { computation_node_id: AstNodeId, op: AstAssignmentOp, lhs: Box<AstExpression>, rhs: Box<AstExpression>, }, Conditional { condition: Box<AstExpression>, consequent: Box<AstExpression>, alternative: Box<AstExpression>, }, FunctionCall { designator: Box<AstExpression>, args_node_id: AstNodeId, args: Vec<AstExpression>, }, Deref { pointer: Box<AstExpression>, }, AddressOf { target: Box<AstExpression>, }, Subscript { expr1: Box<AstExpression>, expr2: Box<AstExpression>, }, Cast { target_type: AstDeclaredType, inner: Box<AstExpression>, is_implicit: bool, }, Ident { name: String, unique_name: AstUniqueName, }, SizeOfExpr { operand: Box<AstExpression>, }, SizeOfType { declared_type: AstDeclaredType, }, AlignOfType { declared_type: AstDeclaredType, }, CharLiteral { literal: String, is_multichar: bool, value: i32, }, StringLiteral { literals: Vec<String>, ascii: Vec<String>, }, IntegerLiteral { literal: String, literal_base: usize, value: u64, kind: AstIntegerLiteralKind, }, FloatLiteral { literal: String, literal_base: usize, value: f64, kind: AstFloatLiteralKind, },
}
The kind of expression, which may in fact be a subexpression inside a tree of a larger expression.

Variants



Unary

Fields



Binary



Assignment

Fields

computation_node_id: AstNodeId


Conditional

Fields

condition: Box<AstExpression>
consequent: Box<AstExpression>
alternative: Box<AstExpression>


FunctionCall

Fields

designator: Box<AstExpression>
args_node_id: AstNodeId


Deref

Fields



AddressOf

Fields



Subscript

Fields



Cast

Fields

target_type: AstDeclaredType
is_implicit: bool


Ident

Fields

name: String
unique_name: AstUniqueName


SizeOfExpr

Fields



SizeOfType

Fields

declared_type: AstDeclaredType


AlignOfType

Fields

declared_type: AstDeclaredType


CharLiteral

Fields

literal: String
is_multichar: bool
value: i32


StringLiteral

Fields

literals: Vec<String>
ascii: Vec<String>


IntegerLiteral

Fields

literal: String
literal_base: usize
value: u64


FloatLiteral

Fields

literal: String
literal_base: usize
value: f64