Enum AstLinkage

pub enum AstLinkage {
    None,
    Internal,
    External,
}
The linkage of an identifier determines the scope that it can be referenced from.

Variants



None



Internal



External

Implementations



impl AstLinkage

pub fn has_linkage(&self) -> bool

Does the identifier have linkage?

In other words, is the linkage Internal or External (but not None). An identifier with linkage must be defined at file scope, but an identifier can be declared with external linkage at any scope.