Enum EnclosingStatement
pub enum EnclosingStatement {
Loop(AstNodeId),
Switch(AstNodeId),
}Expand description
An outer switch or loop statement which is in effect while we are parsing statements inside it.
Variants