Enum EnclosingStatementChain
pub enum EnclosingStatementChain {
Loop {
loop_node_id: AstNodeId,
parent_switch_id: Option<AstNodeId>,
},
Switch {
switch_node_id: AstNodeId,
parent_loop_id: Option<AstNodeId>,
},
}Expand description
An outer switch/loop statement which is in effect while we are parsing statements inside it, plus an option parent switch/loop statement.
Variants