Function parse
pub fn parse(driver: &mut Driver, tokens: Vec<Token>)Expand description
Parses the stream of tokens produced by the lexer and generates an abstract syntax tree (AST) representing the source C code, and then passes ownership of the AST to the semantic analysis stage.