Struct AstBlock
pub struct AstBlock(pub Vec<AstBlockItem>);Expand description
A block is a list of statements and declarations wrapped in braces. A function’s body and a compound statement are both blocks.
Tuple Fields
0: Vec<AstBlockItem>Trait Implementations