Struct AstExpression

pub struct AstExpression { /* private fields */ }
An expression.

Implementations



impl AstExpression

pub fn new(node_id: AstNodeId, kind: AstExpressionKind) -> Self

Creates a new AstExpression with the given node ID and kind.

pub fn deconstruct(self) -> (AstNodeId, AstExpressionKind)

Deconstructs the expression to allow the caller to take ownership of the expression’s fields.

pub fn id(&self) -> AstNodeId

The expression’s unique node ID.

pub fn kind(&self) -> &AstExpressionKind

The kind of expression.

pub fn kind_mut(&mut self) -> &mut AstExpressionKind

The kind of expression.

pub fn is_lvalue(&self) -> bool

Is the AST expression an l-value?

pub fn is_literal(&self) -> bool

Is the AST expression a literal?

pub fn is_arithmetic_literal(&self) -> bool

Is the AST expression an arithmetic (character, integer or floating-point) literal?

pub fn is_single_char_literal(&self) -> bool

Is the AST expression a single character literal?

pub fn is_string_literal(&self) -> bool

Is the AST expression a string literal?

pub fn is_integer_literal(&self) -> bool

Is the AST expression an integer literal?

pub fn is_integer_literal_with_value(&self, value: u64) -> bool

Is the AST expression an integer literal with the given value?

pub fn is_identifier_with_name(&self, declared_name: &str) -> bool

Is the AST expression an identifier of the given declared name?

pub fn is_binary_expr(&self) -> bool

Is the AST expression a binary operation?

pub fn is_binary_expr_with_op(&self, op: AstBinaryOp) -> bool

Is the AST expression a binary operation with the given operator?