Struct AstNodeId
pub struct AstNodeId(/* private fields */);Expand description
A unique numerical identifier for a node in the AST. Identifiers start from 1.
To create a new AstNodeId, call Driver::make_node_id.
Implementations
impl AstNodeId
impl AstNodeId
pub fn null() -> Self
pub fn null() -> Self
Creates a null sentinel value for an AstNodeId.
It’s invalid for a node in the AST to have this value, except when temporarily breaking the invariant.
This function is used when moving a node out from the AST by temporarily replacing it with something else. That temporary replacement node has a null value, until it is replaced again or overwritten.