Enum AstConstantValue
pub enum AstConstantValue {
Integer(AstConstantInteger),
Fp(AstConstantFp),
Pointer(AstType, AstAddressConstant),
String {
ascii: Vec<String>,
},
}Expand description
A constant value that was either parsed from a literal or was evaluated from a constant expression.
Variants
Integer(AstConstantInteger)
A constant integer value.
Fp(AstConstantFp)
Pointer(AstType, AstAddressConstant)
A pointer address constant from evaluating a static storage pointer initializer. See AstAddressConstant for more examples.
static int *p = 0;
static char *str = "hello";String
A constant string value from evaluating a static storage character array initializer.
static char text[4] = "abcd";Implementations
impl AstConstantValue
impl AstConstantValue
pub fn get_ast_type(&self) -> AstType
pub fn get_ast_type(&self) -> AstType
Gets the AST type of the constant value.
pub fn is_pointer_address_constant(&self) -> bool
pub fn is_pointer_address_constant(&self) -> bool
Is the constant value a pointer address constant?
pub fn has_negative_value(&self) -> bool
pub fn has_negative_value(&self) -> bool
Is the constant value below zero? Always false for unsigned types.