Struct AstBasicType
pub struct AstBasicType(pub Vec<AstBasicTypeSpecifier>);Expand description
The basic type of a declaration.
The term ‘basic type’ is not used in the C Standard, but it is used informally when discussing C parsers. The basic type is the first type we see in a declaration before any of the declarators.
unsigned long int *age = 0, calculate(float salary);
~~~~~~~~~~~~~~~~~
typedef int MyInt;
MyInt a = 0, b = 1, c = 2;
~~~~~The subsequent declarators (e.g. *age, calculate(float salary), a, b, c) augment the basic type to create
a derived type. The derived type always modifies the basic type. For example, *age augments the basic type
unsigned long int and creates a derived type of unsigned long int *.
Tuple Fields
0: Vec<AstBasicTypeSpecifier>Implementations
impl AstBasicType
impl AstBasicType
pub fn location(&self) -> SourceLocation
pub fn location(&self) -> SourceLocation
The source location of all specifiers in the basic type.